<?php
/**
 * @brief		File Storage Extension: Blocks
 * @author		<a href='https://www.invisioncommunity.com'>Invision Power Services, Inc.</a>
 * @copyright	(c) Invision Power Services, Inc.
 * @license		https://www.invisioncommunity.com/legal/standards/
 * @package		Invision Community
 * @subpackage	Yellow Pages
 * @since		12 Oct 2020
 */

namespace IPS\ypdatabase\extensions\core\FileStorage;

/* To prevent PHP errors (extending class does not exist) revealing path */
if ( !\defined( '\IPS\SUITE_UNIQUE_KEY' ) )
{
	header( ( isset( $_SERVER['SERVER_PROTOCOL'] ) ? $_SERVER['SERVER_PROTOCOL'] : 'HTTP/1.0' ) . ' 403 Forbidden' );
	exit;
}

/**
 * File Storage Extension: Blocks
 */
class _Blocks
{
    /**
     * Count stored files
     *
     * @return    int
     */
    public function count()
    {
        return \IPS\Settings::i()->yp_header_image ? 1 : 0;
    }

    /**
     * Move stored files
     *
     * @param int $offset This will be sent starting with 0, increasing to get all files stored by this extension
     * @param int $storageConfiguration New storage configuration ID
     * @param int|NULL $oldConfiguration Old storage configuration ID
     * @return    void|int                            An offset integer to use on the next cycle, or nothing
     * @throws    \UnderflowException                    When file record doesn't exist. Indicating there are no more files to move
     */
    public function move($offset, $storageConfiguration, $oldConfiguration = NULL)
    {
        $header = \IPS\Settings::i()->yp_header_image;
        \IPS\Settings::i()->changeValues(array('yp_header_image' => (string)\IPS\File::get($oldConfiguration ?: 'ypdatabase_Blocks', $header)->move($storageConfiguration)));
    }

    /**
     * Check if a file is valid
     *
     * @param string $file The file path to check
     * @return    bool
     */
    public function isValidFile($file)
    {
        $fileObject = \IPS\File::get('ypdatabase_Blocks', \IPS\Settings::i()->yp_header_image);

        if ($fileObject->url == (string)$file) {
            return TRUE;
        } else {
            return FALSE;
        }
    }

    /**
     * Delete all stored files
     *
     * @return    void
     */
    public function delete()
    {
        try {
            \IPS\File::get('ypdatabase_Blocks', \IPS\Settings::i()->yp_header_image)->delete();
        } catch (\Exception $e) {
        }
    }
}