//<?php

/* To prevent PHP errors (extending class does not exist) revealing path */
if (!\defined('\IPS\SUITE_UNIQUE_KEY')) {
    exit;
}

class ypdatabase_hook_locationfilter extends _HOOK_CLASS_
{

    /**
     * Get items with permission check
     *
     * @param array $where Where clause
     * @param string $order MySQL ORDER BY clause (NULL to order by date)
     * @param int|array $limit Limit clause
     * @param string|NULL $permissionKey A key which has a value in the permission map (either of the container or of this class) matching a column ID in core_permission_index or NULL to ignore permissions
     * @param mixed $includeHiddenItems Include hidden items? NULL to detect if currently logged in member has permission, -1 to return public content only, TRUE to return unapproved content and FALSE to only return unapproved content the viewing member submitted
     * @param int $queryFlags Select bitwise flags
     * @param \IPS\Member $member The member (NULL to use currently logged in member)
     * @param bool $joinContainer If true, will join container data (set to TRUE if your $where clause depends on this data)
     * @param bool $joinComments If true, will join comment data (set to TRUE if your $where clause depends on this data)
     * @param bool $joinReviews If true, will join review data (set to TRUE if your $where clause depends on this data)
     * @param bool $countOnly If true will return the count
     * @param array|null $joins Additional arbitrary joins for the query
     * @param mixed $skipPermission If you are getting records from a specific container, pass the container to reduce the number of permission checks necessary or pass TRUE to skip conatiner-based permission. You must still specify this in the $where clause
     * @param bool $joinTags If true, will join the tags table
     * @param bool $joinAuthor If true, will join the members table for the author
     * @param bool $joinLastCommenter If true, will join the members table for the last commenter
     * @param bool $showMovedLinks If true, moved item links are included in the results
     * @return    \IPS\Patterns\ActiveRecordIterator|int
     */
    static public function getItemsWithPermission($where = array(), $order = NULL, $limit = 10, $permissionKey = 'read', $includeHiddenItems = NULL, $queryFlags = 0, ?\IPS\Member $member = NULL, $joinContainer = false, $joinComments = false, $joinReviews = false, $countOnly = false, $joins = NULL, $skipPermission = false, $joinTags = true, $joinAuthor = true, $joinLastCommenter = true, $showMovedLinks = false)
    {
	try
	{
	        $database_id = \IPS\Settings::i()->yp_database_id;
	        if (static::$application == 'cms' && static::$module == 'records' . $database_id) {
	            $fieldsClass = 'IPS\cms\Fields' . $database_id;
	            try {
	                $addressField = $fieldsClass::load('yp_address', 'field_key');
	            } catch (\OutOfRangeException $ex) {
	                return parent::getItemsWithPermission($where, $order, $limit, $permissionKey, $includeHiddenItems, $queryFlags, $member, $joinContainer, $joinComments, $joinReviews, $countOnly, $joins, $skipPermission, $joinTags, $joinAuthor, $joinLastCommenter, $showMovedLinks);
	            }
	            if (array_key_exists('country', \IPS\Request::i()->url()->queryString)) {
	                $value = \IPS\Request::i()->url()->queryString['country'];
	                $where[] = 'cms_custom_database_' . $database_id . '.field_' . $addressField->id . " LIKE '%\"country\":\"" . bin2hex($value) . "\"%'";
                //$where[] = 'JSON_EXTRACT(cms_custom_database_' . $database_id . '.field_' . $addressField->id . ",'$.country') = '" . $value . "'";
	            }
	            if (array_key_exists('city', \IPS\Request::i()->url()->queryString)) {
	                $value = \IPS\Request::i()->url()->queryString['city'];
	                $where[] = 'cms_custom_database_' . $database_id . '.field_' . $addressField->id . " LIKE '%\"city\":\"" . self::utf8_ansi($value) . "\"%'";
                //$where[] = 'JSON_EXTRACT(cms_custom_database_' . $database_id . '.field_' . $addressField->id . ",'$.city') = '" . $value . "'";
	            }
	        }
	
	        return parent::getItemsWithPermission($where, $order, $limit, $permissionKey, $includeHiddenItems, $queryFlags, $member, $joinContainer, $joinComments, $joinReviews, $countOnly, $joins, $skipPermission, $joinTags, $joinAuthor, $joinLastCommenter, $showMovedLinks);
	}
	catch ( \RuntimeException $e )
	{
		if ( method_exists( get_parent_class(), __FUNCTION__ ) )
		{
			return \call_user_func_array( 'parent::' . __FUNCTION__, \func_get_args() );
		}
		else
		{
			throw $e;
		}
	}
    }

    private function utf8_ansi($value) {
	try
	{
	
	        $utf8_ansi2 = array(
	            "\u00c0" =>"À",
	            "\u00c1" =>"Á",
	            "\u00c2" =>"Â",
	            "\u00c3" =>"Ã",
	            "\u00c4" =>"Ä",
	            "\u00c5" =>"Å",
	            "\u00c6" =>"Æ",
	            "\u00c7" =>"Ç",
	            "\u00c8" =>"È",
	            "\u00c9" =>"É",
	            "\u00ca" =>"Ê",
	            "\u00cb" =>"Ë",
	            "\u00cc" =>"Ì",
	            "\u00cd" =>"Í",
	            "\u00ce" =>"Î",
	            "\u00cf" =>"Ï",
	            "\u00d1" =>"Ñ",
	            "\u00d2" =>"Ò",
	            "\u00d3" =>"Ó",
	            "\u00d4" =>"Ô",
	            "\u00d5" =>"Õ",
	            "\u00d6" =>"Ö",
	            "\u00d8" =>"Ø",
	            "\u00d9" =>"Ù",
	            "\u00da" =>"Ú",
	            "\u00db" =>"Û",
	            "\u00dc" =>"Ü",
	            "\u00dd" =>"Ý",
	            "\u00df" =>"ß",
	            "\u00e0" =>"à",
	            "\u00e1" =>"á",
	            "\u00e2" =>"â",
	            "\u00e3" =>"ã",
	            "\u00e4" =>"ä",
	            "\u00e5" =>"å",
	            "\u00e6" =>"æ",
	            "\u00e7" =>"ç",
	            "\u00e8" =>"è",
	            "\u00e9" =>"é",
	            "\u00ea" =>"ê",
	            "\u00eb" =>"ë",
	            "\u00ec" =>"ì",
	            "\u00ed" =>"í",
	            "\u00ee" =>"î",
	            "\u00ef" =>"ï",
	            "\u00f0" =>"ð",
	            "\u00f1" =>"ñ",
	            "\u00f2" =>"ò",
	            "\u00f3" =>"ó",
	            "\u00f4" =>"ô",
	            "\u00f5" =>"õ",
	            "\u00f6" =>"ö",
	            "\u00f8" =>"ø",
	            "\u00f9" =>"ù",
	            "\u00fa" =>"ú",
	            "\u00fb" =>"û",
	            "\u00fc" =>"ü",
	            "\u00fd" =>"ý",
	            "\u00ff" =>"ÿ");
	
	        $value = str_replace(array_values($utf8_ansi2), array_keys($utf8_ansi2), $value);
	        return str_replace("\\", "\\\\\\\\", $value);
	
	}
	catch ( \RuntimeException $e )
	{
		if ( method_exists( get_parent_class(), __FUNCTION__ ) )
		{
			return \call_user_func_array( 'parent::' . __FUNCTION__, \func_get_args() );
		}
		else
		{
			throw $e;
		}
	}
    }

}


