<?php


namespace IPS\ypdatabase\modules\admin\ypdatabase;

/* To prevent PHP errors (extending class does not exist) revealing path */
if (!\defined('\IPS\SUITE_UNIQUE_KEY')) {
    header((isset($_SERVER['SERVER_PROTOCOL']) ? $_SERVER['SERVER_PROTOCOL'] : 'HTTP/1.0') . ' 403 Forbidden');
    exit;
}

/**
 * settings
 */
class _settings extends \IPS\Dispatcher\Controller
{
    /**
     * @brief    Has been CSRF-protected
     */
    public static $csrfProtected = TRUE;

    /**
     * Execute
     *
     * @return    void
     */
    public function execute()
    {
        \IPS\Dispatcher::i()->checkAcpPermission('settings_manage');
        parent::execute();
    }

    /**
     * ...
     *
     * @return    void
     */
    protected function manage()
    {
        $form = new \IPS\Helpers\Form;

        $form->addTab('yp_header_settings');
        $form->add(new \IPS\Helpers\Form\YesNo('yp_enable_header', \IPS\Settings::i()->yp_enable_header, FALSE, array('togglesOn' => array('yp_header_title', 'yp_header_text', 'yp_header_image'))));
        $form->add(new \IPS\Helpers\Form\Translatable('yp_header_title', NULL, FALSE, array('app' => 'ypdatabase', 'key' => 'yp_header_title_value'), NULL, NULL, NULL, 'yp_header_title'));
        $form->add(new \IPS\Helpers\Form\Translatable('yp_header_text', NULL, FALSE, array('app' => 'ypdatabase', 'key' => 'yp_header_text_value', 'textArea' => true), NULL, NULL, NULL, 'yp_header_text'));
        $form->add(new \IPS\Helpers\Form\Upload('yp_header_image', \IPS\Settings::i()->yp_header_image ? \IPS\File::get('ypdatabase_Blocks', \IPS\Settings::i()->yp_header_image) : NULL, FALSE, array('storageExtension' => 'ypdatabase_Blocks'), NULL, NULL, NULL, 'yp_header_image'));


        $form->addTab('yp_block_settings');
        $form->add(new \IPS\Helpers\Form\YesNo('yp_enable_featured', \IPS\Settings::i()->yp_enable_featured));
        $form->add(new \IPS\Helpers\Form\YesNo('yp_enable_recently_added', \IPS\Settings::i()->yp_enable_recently_added));
        $form->add(new \IPS\Helpers\Form\YesNo('yp_enable_top_rated', \IPS\Settings::i()->yp_enable_top_rated));
        $form->add(new \IPS\Helpers\Form\YesNo('yp_enable_latest_updated', \IPS\Settings::i()->yp_enable_latest_updated));
        $form->add(new \IPS\Helpers\Form\YesNo('yp_enable_mostly_viewed', \IPS\Settings::i()->yp_enable_mostly_viewed));


        if ($values = $form->values()) {
            \IPS\Lang::saveCustom( 'ypdatabase', 'yp_header_title_value', $values['yp_header_title']);
            unset($values['yp_header_title']);
            \IPS\Lang::saveCustom('ypdatabase', 'yp_header_text_value', $values['yp_header_text']);
            unset($values['yp_header_text']);
            $values['yp_header_image'] = (string)$values['yp_header_image'];
            $form->saveAsSettings($values);
            /* Clear guest page caches */
            \IPS\Data\Cache::i()->clearAll();
        }

        \IPS\Output::i()->title = \IPS\Member::loggedIn()->language()->addToStack('settings');
        \IPS\Output::i()->output = $form;
    }

    // Create new methods with the same name as the 'do' parameter which should execute it
}