<?php
/**
 * @brief		ypHeaderBlock Widget
 * @author		<a href='https://www.invisioncommunity.com'>Invision Power Services, Inc.</a>
 * @copyright	(c) Invision Power Services, Inc.
 * @license		https://www.invisioncommunity.com/legal/standards/
 * @package		Invision Community
 * @subpackage	ypdatabase
 * @since		12 Oct 2020
 */

namespace IPS\ypdatabase\widgets;

/* To prevent PHP errors (extending class does not exist) revealing path */
if ( !\defined( '\IPS\SUITE_UNIQUE_KEY' ) )
{
	header( ( isset( $_SERVER['SERVER_PROTOCOL'] ) ? $_SERVER['SERVER_PROTOCOL'] : 'HTTP/1.0' ) . ' 403 Forbidden' );
	exit;
}

/**
 * ypHeaderBlock Widget
 */
class _ypHeaderBlock extends \IPS\Widget
{
	/**
	 * @brief	Widget Key
	 */
	public $key = 'ypHeaderBlock';
	
	/**
	 * @brief	App
	 */
	public $app = 'ypdatabase';
		
	/**
	 * @brief	Plugin
	 */
	public $plugin = '';
	
	/**
	 * Initialise this widget
	 *
	 * @return void
	 */ 
	public function init()
	{
		// Use this to perform any set up and to assign a template that is not in the following format:
		// $this->template( array( \IPS\Theme::i()->getTemplate( 'widgets', $this->app, 'front' ), $this->key ) );
		// If you are creating a plugin, uncomment this line:
		// $this->template( array( \IPS\Theme::i()->getTemplate( 'plugins', 'core', 'global' ), $this->key ) );
		// And then create your template at located at plugins/<your plugin>/dev/html/ypHeaderBlock.phtml
		
		
		parent::init();
	}
	
	/**
	 * Specify widget configuration
	 *
	 * @param	null|\IPS\Helpers\Form	$form	Form object
	 * @return	null|\IPS\Helpers\Form
	 */
	public function configuration( &$form=null )
	{
 		$form = parent::configuration( $form );

 		// $form->add( new \IPS\Helpers\Form\XXXX( .... ) );
 		return $form;
 	} 
 	
 	 /**
 	 * Ran before saving widget configuration
 	 *
 	 * @param	array	$values	Values from form
 	 * @return	array
 	 */
 	public function preConfig( $values )
 	{
 		return $values;
 	}

    /**
     * Render a widget
     *
     * @return    string
     */
    public function render()
    {
        /* get total number of categories, entries and locations */
        $database_id = \IPS\Settings::i()->yp_database_id;

        if (isset($database_id)) {
            try {
                $database = \IPS\cms\Databases::load($database_id);
                if (!$database->page_id) {
                    throw new \OutOfRangeException;
                }
            } catch (\OutOfRangeException $e) {
                return '';
            }
        } else {
            return '';
        }

        $categories = 0;
        $items = 0;
        $locations = array();
        $categoryClass = 'IPS\cms\Categories' . $database_id;
        $recordClass = 'IPS\cms\Records' . $database_id;
        foreach ($categoryClass::roots() as $category) {
            $categories++;
            $count = $recordClass::getItemsWithPermission(array(), '', NULL, 'read', \IPS\Content\Hideable::FILTER_AUTOMATIC, 0, NULL, TRUE, FALSE, FALSE, TRUE);
            $items = $items + $count;

        }

        $fieldsClass = 'IPS\cms\Fields' . $database_id;
        $addressField = $fieldsClass::load('yp_address', 'field_key');
        //count locations
        $addresses = iterator_to_array(\IPS\Db::i()->select('field_' . $addressField->id, 'cms_custom_database_' . $database_id, array('field_' . $addressField->id . ' is NOT NULL')));
        foreach ($addresses as $address) {
            $location = json_decode($address);
            if (is_object($location)) {
                if (!in_array($location->city, $locations)) {
                    $locations[] = $location->city;
                }
            }
        }

        return $this->output($database, $categories, $items, \count($locations));
    }
}