<?php
/**
 * @brief		ypLocationsBlock Widget
 * @author		<a href='https://www.invisioncommunity.com'>Invision Power Services, Inc.</a>
 * @copyright	(c) Invision Power Services, Inc.
 * @license		https://www.invisioncommunity.com/legal/standards/
 * @package		Invision Community
 * @subpackage	ypdatabase
 * @since		12 Oct 2020
 */

namespace IPS\ypdatabase\widgets;

/* To prevent PHP errors (extending class does not exist) revealing path */
if ( !\defined( '\IPS\SUITE_UNIQUE_KEY' ) )
{
	header( ( isset( $_SERVER['SERVER_PROTOCOL'] ) ? $_SERVER['SERVER_PROTOCOL'] : 'HTTP/1.0' ) . ' 403 Forbidden' );
	exit;
}

/**
 * ypLocationsBlock Widget
 */
class _ypLocationsBlock extends \IPS\Widget
{
	/**
	 * @brief	Widget Key
	 */
	public $key = 'ypLocationsBlock';
	
	/**
	 * @brief	App
	 */
	public $app = 'ypdatabase';
		
	/**
	 * @brief	Plugin
	 */
	public $plugin = '';
	
	/**
	 * Initialise this widget
	 *
	 * @return void
	 */ 
	public function init()
	{
		// Use this to perform any set up and to assign a template that is not in the following format:
		// $this->template( array( \IPS\Theme::i()->getTemplate( 'widgets', $this->app, 'front' ), $this->key ) );
		// If you are creating a plugin, uncomment this line:
		// $this->template( array( \IPS\Theme::i()->getTemplate( 'plugins', 'core', 'global' ), $this->key ) );
		// And then create your template at located at plugins/<your plugin>/dev/html/ypLocationsBlock.phtml
		
		
		parent::init();
	}
	
	/**
	 * Specify widget configuration
	 *
	 * @param	null|\IPS\Helpers\Form	$form	Form object
	 * @return	null|\IPS\Helpers\Form
	 */
	public function configuration( &$form=null )
	{
 		$form = parent::configuration( $form );

 		// $form->add( new \IPS\Helpers\Form\XXXX( .... ) );
 		return $form;
 	} 
 	
 	 /**
 	 * Ran before saving widget configuration
 	 *
 	 * @param	array	$values	Values from form
 	 * @return	array
 	 */
 	public function preConfig( $values )
 	{
 		return $values;
 	}

    /**
     * Render a widget
     *
     * @return    string
     */
    public function render()
    {
        if (isset(\IPS\cms\Databases\Dispatcher::i()->categoryId) && \IPS\cms\Databases\_Dispatcher::i()->databaseId == \IPS\Settings::i()->yp_database_id) {
            $database_id = \IPS\Settings::i()->yp_database_id;
            $fieldsClass = 'IPS\cms\Fields' . $database_id;
            try {
                $addressField = $fieldsClass::load('yp_address', 'field_key');
            } catch (\OutOfRangeException $ex) {
                return "";
            }
            $rows = iterator_to_array(\IPS\Db::i()->select('*', 'cms_custom_database_'. $database_id, array('category_id=? and field_'.$addressField->id.'<>?' , \IPS\cms\Databases\Dispatcher::i()->categoryId, 'null')));
            $classRecords = 'IPS\cms\Records'.$database_id;
            /*$where = array('cms_custom_database_'. $database_id. '.category_id=? and field_'.$addressField->id.'<>?' , \IPS\cms\Databases\Dispatcher::i()->categoryId, 'null');
            $rows = iterator_to_array($classRecords::getItemsWithPermission(array($where)));*/
            if (!\count($rows)) {
                return "";
            }
            $locations = array();
            foreach ($rows as $row) {
                $record = $classRecords::constructFromData($row);
                if ($record->canView()) {
                    $address = json_decode($record->customFieldsForDisplay('raw')['yp_address']);
                    if (is_object($address)) {
                        if (!empty($address->country) && !isset($locations[$address->country])) {
                            $locations[$address->country][] = $address->city;
                        }
                        if (!in_array($address->city, $locations[$address->country])) {
                            $locations[$address->country][] = $address->city;
                        }
                    }
                }
            }
            $category = \IPS\cms\Categories::load(\IPS\cms\Databases\Dispatcher::i()->categoryId);
            $url = $category->url()->stripQueryString('country');
            $url = $url->stripQueryString('city');
            return $this->output($locations, $url);    // Note you MUST route output through $this->output() rather than calling \IPS\Theme::i()->getTemplate() because of the way widgets are cached
        }
        return '';
    }
}